##  Managing Fact Sheets Created by Transformations
The Fact Sheets created as part of the Transformation will maintain the status - 'Planned' until you decide to execute the Transformation. In Reports, you can use it as a filter criterion to narrow down to Fact Sheets created by Transformations. This filter criteria can be accessed under Transformation Status.
![Transformation Status filter](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274681977a44101488a6936f1b28cee9_LowRes.png)
Transformation Status filter
For proper deletion of a Fact Sheet created by a Transformation, instead of archiving it through the Fact Sheet menu, delete the Transformation from which it was created. This action will promptly remove the Fact Sheet from the inventory along with all associated relations.
![Deleting Fact Sheet created by a Transformation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274934917a441014b675fa2d62a69a05_LowRes.png)
Deleting Fact Sheet created by a Transformation
